==> jc-1.4.0.tar.gz: gnu/xml/pipeline/ValidationConsumer__24EmptyRecognizer.h <==
// final class gnu.xml.pipeline.ValidationConsumer$EmptyRecognizer

// class file dependencies
// @dep_class acbc9c7d9c7ee1e7 gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer
// @dep_class c3c82d7a3ea2ae0e gnu_xml_pipeline_ValidationConsumer__24Recognizer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_ValidationConsumer__24Recognizer

#include "gnu/xml/pipeline/ValidationConsumer__24Recognizer.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method$_init$e3a1cb21679f8576(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *);

// Virtual methods
extern jboolean _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method$acceptCharacters$f1bf4dfd6e39a802(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *);
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method$acceptElement$99cdc60944f2d23c(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method_info$acceptCharacters$f1bf4dfd6e39a802;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method_info$acceptElement$99cdc60944f2d23c;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods {
	jboolean	(*acceptCharacters$f1bf4dfd6e39a802)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *);
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*acceptElement$99cdc60944f2d23c)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/ValidationConsumer__24EmptyRecognizer.h <==
// final class gnu.xml.pipeline.ValidationConsumer$EmptyRecognizer

// class file dependencies
// @dep_class acbc9c7d9c7ee1e7 gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer
// @dep_class c3c82d7a3ea2ae0e gnu_xml_pipeline_ValidationConsumer__24Recognizer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_ValidationConsumer__24Recognizer

#include "gnu/xml/pipeline/ValidationConsumer__24Recognizer.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method$_init$e3a1cb21679f8576(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method$acceptCharacters$f1bf4dfd6e39a802(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method$acceptElement$99cdc60944f2d23c(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method_info$acceptCharacters$f1bf4dfd6e39a802;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$method_info$acceptElement$99cdc60944f2d23c;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods {
	jboolean	(*acceptCharacters$f1bf4dfd6e39a802)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*acceptElement$99cdc60944f2d23c)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24EmptyRecognizer_H_ */
